# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdWatermark(Component):
    """An AntdWatermark component.
水印组件AntdWatermark

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string; optional):
    当前组件css类名.

- markClassName (string; optional):
    水印层css类名.

- markStyle (dict; optional):
    水印层css样式.

- content (string | list of strings; optional):
    配置水印内容，传入数组时渲染多行水印.

- rotate (number; default -22):
    水印旋转角度 默认值：`-22`.

- zIndex (number; optional):
    水印z-index.

- fontColor (string; optional):
    文字水印颜色.

- fontSize (number; default 16):
    文字水印字体大小 默认值：`16`.

- gapX (number; default 212):
    水印之间的水平像素间距 默认值：`212`.

- gapY (number; default 222):
    水印之间的垂直像素间距 默认值：`222`.

- image (string; optional):
    图片水印地址.

- width (number; optional):
    图片水印像素宽度.

- height (number; optional):
    图片水印像素高度.

- inherit (boolean; default True):
    是否将水印传导给`AntdModal`、`AntdDrawer`等弹出类组件 默认值：`True`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdWatermark'


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[str] = None,
        markClassName: typing.Optional[str] = None,
        markStyle: typing.Optional[dict] = None,
        content: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rotate: typing.Optional[NumberType] = None,
        zIndex: typing.Optional[NumberType] = None,
        fontColor: typing.Optional[str] = None,
        fontSize: typing.Optional[NumberType] = None,
        gapX: typing.Optional[NumberType] = None,
        gapY: typing.Optional[NumberType] = None,
        image: typing.Optional[str] = None,
        width: typing.Optional[NumberType] = None,
        height: typing.Optional[NumberType] = None,
        inherit: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'markClassName', 'markStyle', 'content', 'rotate', 'zIndex', 'fontColor', 'fontSize', 'gapX', 'gapY', 'image', 'width', 'height', 'inherit', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'markClassName', 'markStyle', 'content', 'rotate', 'zIndex', 'fontColor', 'fontSize', 'gapX', 'gapY', 'image', 'width', 'height', 'inherit', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdWatermark, self).__init__(children=children, **args)

setattr(AntdWatermark, "__init__", _explicitize_args(AntdWatermark.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdInputNumber(Component):
    """An AntdInputNumber component.
数值输入框组件AntdInputNumber

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- name (string; optional):
    配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

- enableBatchControl (boolean; default True):
    控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

- addonBefore (a list of or a singular dash component, string or number; optional):
    组件型，前置标签内容.

- addonAfter (a list of or a singular dash component, string or number; optional):
    组件型，后置标签内容.

- prefix (a list of or a singular dash component, string or number; optional):
    组件型，前缀内嵌内容.

- suffix (a list of or a singular dash component, string or number; optional):
    组件型，后缀内嵌内容.

- autoFocus (boolean; default False):
    是否自动获取焦点 默认值：`False`.

- controls (boolean; default True):
    是否显示增减数值按钮 默认值：`True`.

- keyboard (boolean; default True):
    是否允许通过键盘上下方向键控制数值 默认值：`True`.

- min (number | string; optional):
    允许输入的数值下限，默认无限制.

- max (number | string; optional):
    允许输入的数值上限，默认无限制.

- step (number | string; optional):
    数值增减步长.

- precision (number; optional):
    数值精度.

- stringMode (boolean; default False):
    是否开启字符串模式，用于在接受超高精度数值输入时不丢失精度，开启后，参数`min`、`max`、`step`、`value`、`defaultValue`均需要设置为字符型
    默认值：`False`.

- disabled (boolean; default False):
    是否禁用当前组件 默认值：`False`.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

- bordered (boolean; default True):
    是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

- variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
    形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

- placeholder (string; optional):
    输入框占位文字内容.

- value (number | string; optional):
    监听或设置已输入值.

- defaultValue (number | string; optional):
    初始化已输入值.

- debounceValue (number | string; optional):
    监听防抖版本的已输入值.

- debounceWait (number; default 0):
    防抖延时时长，单位：毫秒 默认值：`0`.

- nSubmit (number; default 0):
    监听输入框聚焦状态下，键盘enter键累计点按次数 默认值：`0`.

- status (a value equal to: 'error', 'warning'; optional):
    控制校验状态，可选项有`'error'`、`'warning'`.

- readOnly (boolean; optional):
    是否渲染为只读状态 默认值：`False`.

- batchPropsNames (list of strings; optional):
    需要纳入[批量属性监听](/batch-props-values)的若干属性名.

- batchPropsValues (dict; optional):
    监听`batchPropsNames`中指定的若干属性值.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- persistence (boolean | string | number; optional):
    是否开启[属性持久化](/prop-persistence).

- persisted_props (list of a value equal to: 'value's; default ['value']):
    开启属性持久化功能的若干属性名，可选项有`'md5Value'` 默认值：`['md5Value']`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
    默认值：`'local'`."""
    _children_props: typing.List[str] = ['addonBefore', 'addonAfter', 'prefix', 'suffix']
    _base_nodes = ['addonBefore', 'addonAfter', 'prefix', 'suffix', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdInputNumber'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        addonBefore: typing.Optional[ComponentType] = None,
        addonAfter: typing.Optional[ComponentType] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffix: typing.Optional[ComponentType] = None,
        autoFocus: typing.Optional[bool] = None,
        controls: typing.Optional[bool] = None,
        keyboard: typing.Optional[bool] = None,
        min: typing.Optional[typing.Union[NumberType, str]] = None,
        max: typing.Optional[typing.Union[NumberType, str]] = None,
        step: typing.Optional[typing.Union[NumberType, str]] = None,
        precision: typing.Optional[NumberType] = None,
        stringMode: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal["small", "middle", "large"]] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal["outlined", "borderless", "filled", "underlined"]] = None,
        placeholder: typing.Optional[str] = None,
        value: typing.Optional[typing.Union[NumberType, str]] = None,
        defaultValue: typing.Optional[typing.Union[NumberType, str]] = None,
        debounceValue: typing.Optional[typing.Union[NumberType, str]] = None,
        debounceWait: typing.Optional[NumberType] = None,
        nSubmit: typing.Optional[NumberType] = None,
        status: typing.Optional[Literal["error", "warning"]] = None,
        readOnly: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal["value"]]] = None,
        persistence_type: typing.Optional[Literal["local", "session", "memory"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'name', 'enableBatchControl', 'addonBefore', 'addonAfter', 'prefix', 'suffix', 'autoFocus', 'controls', 'keyboard', 'min', 'max', 'step', 'precision', 'stringMode', 'disabled', 'size', 'bordered', 'variant', 'placeholder', 'value', 'defaultValue', 'debounceValue', 'debounceWait', 'nSubmit', 'status', 'readOnly', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'name', 'enableBatchControl', 'addonBefore', 'addonAfter', 'prefix', 'suffix', 'autoFocus', 'controls', 'keyboard', 'min', 'max', 'step', 'precision', 'stringMode', 'disabled', 'size', 'bordered', 'variant', 'placeholder', 'value', 'defaultValue', 'debounceValue', 'debounceWait', 'nSubmit', 'status', 'readOnly', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdInputNumber, self).__init__(**args)

setattr(AntdInputNumber, "__init__", _explicitize_args(AntdInputNumber.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdSpin(Component):
    """An AntdSpin component.
加载动画组件AntdSpin

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- wrapperClassName (string | dict; optional):
    外层容器css类名.

- spinning (boolean; default False):
    是否处于加载中状态.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    默认加载状态图标的尺寸，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

- delay (number; optional):
    加载动画渲染延时，单位：毫秒 默认值：`0`.

- text (string; optional):
    加载动画提示文字.

- fullscreen (boolean; default False):
    是否开启全屏模式 默认值：`False`.

- debug (boolean; default False):
    是否开启debug模式，开启后，每次动画加载都会在开发者工具的控制台打印相关`prop`信息 默认值：`False`.

- listenPropsMode (a value equal to: 'default', 'exclude', 'include'; default 'default'):
    监听模式，可选项有`'default'`、`'exclude'`、`'include'` 默认值：`'default'`.

- excludeProps (list of strings; optional):
    `listenPropsMode='exclude'`时，设置需要排除监听的回调目标列表，格式如`['组件id1.组件属性1',
    '组件id2.组件属性2', ...]`.

- includeProps (list of strings; optional):
    `listenPropsMode='include'`时，设置需要包含监听的回调目标列表，格式如`['组件id1.组件属性1',
    '组件id2.组件属性2', ...]`.

- indicator (a list of or a singular dash component, string or number; optional):
    组件型，自定义加载状态图标.

- manual (boolean; default False):
    是否开启手动控制模式，开启后是否处于加载状态将由`spinning`参数控制，与内部元素参与的回调状态无关 默认值：`False`.

- percent (number | a value equal to: 'auto'; optional):
    控制加载中状态下的环状进度渲染形式，传入0到100之间数值型时表示实际进度，传入`'auto'`时会预估一个永远不会停止的进度.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['indicator']
    _base_nodes = ['indicator', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSpin'


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        wrapperClassName: typing.Optional[typing.Union[str, dict]] = None,
        spinning: typing.Optional[bool] = None,
        size: typing.Optional[Literal["small", "middle", "large"]] = None,
        delay: typing.Optional[NumberType] = None,
        text: typing.Optional[str] = None,
        fullscreen: typing.Optional[bool] = None,
        debug: typing.Optional[bool] = None,
        listenPropsMode: typing.Optional[Literal["default", "exclude", "include"]] = None,
        excludeProps: typing.Optional[typing.Sequence[str]] = None,
        includeProps: typing.Optional[typing.Sequence[str]] = None,
        indicator: typing.Optional[ComponentType] = None,
        manual: typing.Optional[bool] = None,
        percent: typing.Optional[typing.Union[NumberType, Literal["auto"]]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'wrapperClassName', 'spinning', 'size', 'delay', 'text', 'fullscreen', 'debug', 'listenPropsMode', 'excludeProps', 'includeProps', 'indicator', 'manual', 'percent', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'wrapperClassName', 'spinning', 'size', 'delay', 'text', 'fullscreen', 'debug', 'listenPropsMode', 'excludeProps', 'includeProps', 'indicator', 'manual', 'percent', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSpin, self).__init__(children=children, **args)

setattr(AntdSpin, "__init__", _explicitize_args(AntdSpin.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdSplitter(Component):
    """An AntdSplitter component.
分隔面板组件AntdSplitter

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- layout (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
    布局方向，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

- items (list of dicts; required):
    配置分隔面板子项.

    `items` is a list of dicts with keys:

    - key (string; optional):
        当前子项唯一识别`key`.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - style (dict; optional):
        当前子项`css`样式.

    - className (string; optional):
        当前子项`css`类名.

    - defaultSize (number

      Or string; optional):
        初始面板尺寸，支持数字`px`或者文字`'百分比%'`类型.

    - size (number | string; optional):
        面板尺寸，支持数字`px`或者文字`'百分比%'`类型.

    - min (number | string; optional):
        最小尺寸，支持数字`px`或者文字`'百分比%'`类型.

    - max (number | string; optional):
        最大尺寸，支持数字`px`或者文字`'百分比%'`类型.

    - collapsible (dict; optional):
        是否可折叠 默认值：`False`.

        `collapsible` is a boolean | dict with keys:

        - start (boolean; optional)

        - end (boolean; optional)

    - resizable (boolean; optional):
        是否开启拖拽伸缩 默认值：`True`.

- lazy (boolean; default False):
    是否开启延迟渲染模式，开启后面板将在拖拽调整完成后才进行更新渲染 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['items[].children']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSplitter'
    ItemsCollapsible = TypedDict(
        "ItemsCollapsible",
            {
            "start": NotRequired[bool],
            "end": NotRequired[bool]
        }
    )

    Items = TypedDict(
        "Items",
            {
            "key": NotRequired[str],
            "children": NotRequired[ComponentType],
            "style": NotRequired[dict],
            "className": NotRequired[str],
            "defaultSize": NotRequired[typing.Union[NumberType, str]],
            "size": NotRequired[typing.Union[NumberType, str]],
            "min": NotRequired[typing.Union[NumberType, str]],
            "max": NotRequired[typing.Union[NumberType, str]],
            "collapsible": NotRequired[typing.Union[bool, "ItemsCollapsible"]],
            "resizable": NotRequired[bool]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        layout: typing.Optional[Literal["horizontal", "vertical"]] = None,
        items: typing.Optional[typing.Sequence["Items"]] = None,
        lazy: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'layout', 'items', 'lazy', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'layout', 'items', 'lazy', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['items']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdSplitter, self).__init__(**args)

setattr(AntdSplitter, "__init__", _explicitize_args(AntdSplitter.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdCascader(Component):
    """An AntdCascader component.
级联选择组件AntdCascader

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- popupClassName (string; optional):
    展开菜单css类名.

- name (string; optional):
    配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

- enableBatchControl (boolean; default True):
    控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'ru-ru'`（俄语）
    默认值：`'zh-cn'`.

- optionsMode (a value equal to: 'tree', 'flat'; default 'tree'):
    对应`options`格式的渲染模式，可选项有`'tree'`（树形模式）、`'flat'`（扁平模式） 默认值：`'tree'`.

- options (list; required):
    定义构造级联选择所需的数据结构，与`optionsMode`一致.

- optionsNodeKeyToLabel (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
    针对级联结构中的指定节点，定义作为标题的组件型内容，优先级高于`options`中对应的`label`值.

- optionFilterProp (a value equal to: 'value', 'label'; default 'label'):
    选项关键词搜索时的目标字段，可选项有`'value'`、`'label'` 默认值：`'label'`.

- panelMode (boolean; default False):
    是否开启内嵌面板模式 默认值：`False`.

- disabled (boolean; default False):
    是否禁用当前组件 默认值：`False`.

- changeOnSelect (boolean; default False):
    是否当级联选择中的任意节点被选择时均进行选中值更新 默认值：`False`.

- size (a value equal to: 'small', 'middle', 'large'; optional):
    当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

- bordered (boolean; default True):
    是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

- variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
    形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

- placeholder (string; optional):
    输入框占位文字内容.

- placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
    选择菜单展开方向，可选项有`'bottomLeft'`、`'bottomRight'`、`'topLeft'`、`'topRight'`
    默认值：`'bottomLeft'`.

- value (list of string | numbers | list of list of string | numberss; optional):
    监听或设置已选值.

- defaultValue (list of string | numbers | list of list of string | numberss; optional):
    初始化已选值.

- multiple (boolean; default False):
    是否开启多选模式 默认值：`False`.

- maxTagCount (number | a value equal to: 'responsive'; optional):
    当`multiple=True`时，已选值展示的最大数量.

- expandTrigger (a value equal to: 'click', 'hover'; default 'click'):
    选择菜单展开触发方式，可选项有`'click'`、`'hover'` 默认值：`'click'`.

- status (a value equal to: 'error', 'warning'; optional):
    控制校验状态，可选项有`'error'`、`'warning'`.

- allowClear (boolean; default True):
    是否允许一键清空已选值 默认值：`True`.

- autoFocus (boolean; default False):
    是否自动获取焦点 默认值：`False`.

- showCheckedStrategy (a value equal to: 'show-parent', 'show-child'; optional):
    已选项回填策略，可选项有`'show-parent'`、`'show-child'`.

- prefix (a list of or a singular dash component, string or number; optional):
    组件型，前缀内嵌内容.

- suffixIcon (a list of or a singular dash component, string or number; optional):
    自定义选择框后缀图标内容.

- readOnly (boolean; optional):
    是否渲染为只读状态 默认值：`False`.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

- batchPropsNames (list of strings; optional):
    需要纳入[批量属性监听](/batch-props-values)的若干属性名.

- batchPropsValues (dict; optional):
    监听`batchPropsNames`中指定的若干属性值.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- persistence (boolean | string | number; optional):
    是否开启[属性持久化](/prop-persistence).

- persisted_props (list of a value equal to: 'value's; optional):
    开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
    属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
    默认值：`'local'`."""
    _children_props: typing.List[str] = ['optionsNodeKeyToLabel{}', 'prefix', 'suffixIcon']
    _base_nodes = ['prefix', 'suffixIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCascader'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal["zh-cn", "en-us", "de-de", "ru-ru"]] = None,
        optionsMode: typing.Optional[Literal["tree", "flat"]] = None,
        options: typing.Optional[typing.Union[typing.Any, typing.Sequence[typing.Any]]] = None,
        optionsNodeKeyToLabel: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        optionFilterProp: typing.Optional[Literal["value", "label"]] = None,
        panelMode: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        changeOnSelect: typing.Optional[bool] = None,
        size: typing.Optional[Literal["small", "middle", "large"]] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal["outlined", "borderless", "filled", "underlined"]] = None,
        placeholder: typing.Optional[str] = None,
        placement: typing.Optional[Literal["bottomLeft", "bottomRight", "topLeft", "topRight"]] = None,
        value: typing.Optional[typing.Union[typing.Sequence[typing.Union[str, NumberType]], typing.Sequence[typing.Sequence[typing.Union[str, NumberType]]]]] = None,
        defaultValue: typing.Optional[typing.Union[typing.Sequence[typing.Union[str, NumberType]], typing.Sequence[typing.Sequence[typing.Union[str, NumberType]]]]] = None,
        multiple: typing.Optional[bool] = None,
        maxTagCount: typing.Optional[typing.Union[NumberType, Literal["responsive"]]] = None,
        expandTrigger: typing.Optional[Literal["click", "hover"]] = None,
        status: typing.Optional[Literal["error", "warning"]] = None,
        allowClear: typing.Optional[bool] = None,
        autoFocus: typing.Optional[bool] = None,
        showCheckedStrategy: typing.Optional[Literal["show-parent", "show-child"]] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffixIcon: typing.Optional[ComponentType] = None,
        readOnly: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal["parent", "body"]] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal["value"]]] = None,
        persistence_type: typing.Optional[Literal["local", "session", "memory"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'popupClassName', 'name', 'enableBatchControl', 'locale', 'optionsMode', 'options', 'optionsNodeKeyToLabel', 'optionFilterProp', 'panelMode', 'disabled', 'changeOnSelect', 'size', 'bordered', 'variant', 'placeholder', 'placement', 'value', 'defaultValue', 'multiple', 'maxTagCount', 'expandTrigger', 'status', 'allowClear', 'autoFocus', 'showCheckedStrategy', 'prefix', 'suffixIcon', 'readOnly', 'popupContainer', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'popupClassName', 'name', 'enableBatchControl', 'locale', 'optionsMode', 'options', 'optionsNodeKeyToLabel', 'optionFilterProp', 'panelMode', 'disabled', 'changeOnSelect', 'size', 'bordered', 'variant', 'placeholder', 'placement', 'value', 'defaultValue', 'multiple', 'maxTagCount', 'expandTrigger', 'status', 'allowClear', 'autoFocus', 'showCheckedStrategy', 'prefix', 'suffixIcon', 'readOnly', 'popupContainer', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['options']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdCascader, self).__init__(**args)

setattr(AntdCascader, "__init__", _explicitize_args(AntdCascader.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdMenu(Component):
    """An AntdMenu component.
导航菜单组件AntdMenu

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- expandIcon (dict; optional):
    自定义展开图标，建议仅在`mode='inline'`时使用字典类型.

    `expandIcon` is a a list of or a singular dash component, string
    or number | dict with keys:

    - expand (a list of or a singular dash component, string or number; optional):
        展开图标.

    - collapse (a list of or a singular dash component, string or number; optional):
        收起图标.

- menuItems (list; optional):
    导航菜单数据结构.

- menuItemKeyToTitle (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
    为指定节点定义组件型菜单项标题，优先级高于menuItems中对应节点的title属性.

- menuItemKeyToIcon (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
    为指定节点定义组件型菜单项图标元素，优先级高于menuItems中对应节点的icon属性.

- mode (a value equal to: 'vertical', 'horizontal', 'inline'; default 'vertical'):
    显示模式，可选项有`'vertical'`、`'horizontal'`、`'inline'` 默认值：`'vertical'`.

- theme (a value equal to: 'light', 'dark'; default 'light'):
    主题，可选项有`'light'`、`'dark'` 默认值：`'light'`.

- currentKey (string; optional):
    监听或设置当前已选中菜单项key值.

- currentItem (dict; optional):
    监听当前已选中菜单项信息.

- currentKeyPath (list; optional):
    监听当前已选中菜单项key值路径信息.

- currentItemPath (list; optional):
    监听当前已选中菜单项路径信息.

- openKeys (list of strings; optional):
    监听或设置当前已展开子菜单项key值.

- onlyExpandCurrentSubMenu (boolean; default False):
    是否只展开当前选中项的父级菜单 默认值：`False`.

- defaultOpenKeys (list of strings; optional):
    默认展开的菜单项key值.

- defaultSelectedKey (string; optional)

- renderCollapsedButton (boolean; default False):
    是否渲染菜单折叠状态控制按钮 默认值：`False`.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    菜单展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

- inlineCollapsed (boolean; optional):
    当前菜单是否折叠，仅inline模式下有效 默认值：`False`.

- inlineIndent (number; default 24):
    inline模式下，子菜单相对上一级的像素缩进宽度 默认值：`24`.

- triggerSubMenuAction (a value equal to: 'hover', 'click'; default 'hover'):
    `SubMenu`展开/关闭的触发行为，可选项有`'hover'`、`'click'`，`mode='inline'`下无效
    默认值：`'hover'`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- persistence (boolean | string | number; optional):
    是否为当前组件开启持久化功能.

- persisted_props (list of a value equal to: 'currentKey', 'openKeys's; optional):
    当前组件启用持久化的属性值数组，可选项有`'currentKey'`、`'openKeys'`
    默认值：`['currentKey', 'openKeys']`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
    当前组件的属性持久化存储类型 默认值：`'local'`."""
    _children_props: typing.List[str] = ['expandIcon', 'expandIcon.expand', 'expandIcon.collapse', 'menuItemKeyToTitle{}', 'menuItemKeyToIcon{}']
    _base_nodes = ['expandIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdMenu'
    ExpandIcon = TypedDict(
        "ExpandIcon",
            {
            "expand": NotRequired[ComponentType],
            "collapse": NotRequired[ComponentType]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        expandIcon: typing.Optional[typing.Union[ComponentType, "ExpandIcon"]] = None,
        menuItems: typing.Optional[typing.Sequence] = None,
        menuItemKeyToTitle: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        menuItemKeyToIcon: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        mode: typing.Optional[Literal["vertical", "horizontal", "inline"]] = None,
        theme: typing.Optional[Literal["light", "dark"]] = None,
        currentKey: typing.Optional[str] = None,
        currentItem: typing.Optional[dict] = None,
        currentKeyPath: typing.Optional[typing.Sequence] = None,
        currentItemPath: typing.Optional[typing.Sequence] = None,
        openKeys: typing.Optional[typing.Sequence[str]] = None,
        onlyExpandCurrentSubMenu: typing.Optional[bool] = None,
        defaultOpenKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultSelectedKey: typing.Optional[str] = None,
        renderCollapsedButton: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal["parent", "body"]] = None,
        inlineCollapsed: typing.Optional[bool] = None,
        inlineIndent: typing.Optional[NumberType] = None,
        triggerSubMenuAction: typing.Optional[Literal["hover", "click"]] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal["currentKey", "openKeys"]]] = None,
        persistence_type: typing.Optional[Literal["local", "session", "memory"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'expandIcon', 'menuItems', 'menuItemKeyToTitle', 'menuItemKeyToIcon', 'mode', 'theme', 'currentKey', 'currentItem', 'currentKeyPath', 'currentItemPath', 'openKeys', 'onlyExpandCurrentSubMenu', 'defaultOpenKeys', 'defaultSelectedKey', 'renderCollapsedButton', 'popupContainer', 'inlineCollapsed', 'inlineIndent', 'triggerSubMenuAction', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'expandIcon', 'menuItems', 'menuItemKeyToTitle', 'menuItemKeyToIcon', 'mode', 'theme', 'currentKey', 'currentItem', 'currentKeyPath', 'currentItemPath', 'openKeys', 'onlyExpandCurrentSubMenu', 'defaultOpenKeys', 'defaultSelectedKey', 'renderCollapsedButton', 'popupContainer', 'inlineCollapsed', 'inlineIndent', 'triggerSubMenuAction', 'data-*', 'aria-*', 'persistence', 'persisted_props', 'persistence_type']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdMenu, self).__init__(**args)

setattr(AntdMenu, "__init__", _explicitize_args(AntdMenu.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdFormItem(Component):
    """An AntdFormItem component.
表单项组件AntdFormItem

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌相关常用表单输入类组件.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- required (boolean; default False):
    是否显示表示必填项的额外“*”标识 默认值：`False`.

- labelCol (dict; optional):
    配置表单项标签部分相关参数，优先级高于所属`AntdForm`中的`labelCol`参数.

    `labelCol` is a dict with keys:

    - span (number; optional):
        标签部分所占宽度份数（总份数24）.

    - offset (number; optional):
        标签部分向右偏移宽度份数.

    - flex (string | number; optional):
        同css中的flex属性，用于更灵活的控制标签部分所占宽度.

- wrapperCol (dict; optional):
    配置表单项控件部分相关参数，优先级高于所属`AntdForm`中的`labelCol`参数.

    `wrapperCol` is a dict with keys:

    - span (number; optional):
        控件部分所占宽度份数（总份数24）.

    - offset (number; optional):
        控件部分向右偏移宽度份数.

    - flex (string | number; optional):
        同css中的flex属性，用于更灵活的控制控件部分所占宽度.

- colon (boolean; optional):
    当`layout='horizontal'`时，控制是否在表单项标签部分末尾添加冒号，优先级高于所属`AntdForm`中的`colon`参数.

- label (a list of or a singular dash component, string or number; optional):
    组件型，当前表单项标签内容.

- labelAlign (a value equal to: 'left', 'right'; optional):
    表单项标签部分文本对齐方式，可选项有`'left'`、`'right'`，优先级高于所属`AntdForm`中的`labelAlign`参数
    默认值：`'right'`.

- tooltip (a list of or a singular dash component, string or number; optional):
    组件型，当前表单项标签内容后的额外文字提示信息.

- extra (a list of or a singular dash component, string or number; optional):
    组件型，当前表单项额外提示信息.

- validateStatus (a value equal to: 'success', 'warning', 'error', 'validating'; optional):
    控制校验状态，可选项有`'success'`、`'warning'`、`'error'`、`'validating'`.

- hasFeedback (boolean; default False):
    与`validateStatus`设定的状态对应，用于控制是否显示额外的状态图标 默认值：`False`.

- help (a list of or a singular dash component, string or number; optional):
    组件型，与`validateStatus`状态一致的额外说明内容.

- hidden (boolean; default False):
    是否隐藏当前字段 默认值：`False`.

- layout (a value equal to: 'horizontal', 'vertical'; optional):
    表单项布局模式，可选项有`'horizontal'`、`'vertical'`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['label', 'tooltip', 'extra', 'help']
    _base_nodes = ['label', 'tooltip', 'extra', 'help', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFormItem'
    LabelCol = TypedDict(
        "LabelCol",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "flex": NotRequired[typing.Union[str, NumberType]]
        }
    )

    WrapperCol = TypedDict(
        "WrapperCol",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "flex": NotRequired[typing.Union[str, NumberType]]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        required: typing.Optional[bool] = None,
        labelCol: typing.Optional["LabelCol"] = None,
        wrapperCol: typing.Optional["WrapperCol"] = None,
        colon: typing.Optional[bool] = None,
        label: typing.Optional[ComponentType] = None,
        labelAlign: typing.Optional[Literal["left", "right"]] = None,
        tooltip: typing.Optional[ComponentType] = None,
        extra: typing.Optional[ComponentType] = None,
        validateStatus: typing.Optional[Literal["success", "warning", "error", "validating"]] = None,
        hasFeedback: typing.Optional[bool] = None,
        help: typing.Optional[ComponentType] = None,
        hidden: typing.Optional[bool] = None,
        layout: typing.Optional[Literal["horizontal", "vertical"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'required', 'labelCol', 'wrapperCol', 'colon', 'label', 'labelAlign', 'tooltip', 'extra', 'validateStatus', 'hasFeedback', 'help', 'hidden', 'layout', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'required', 'labelCol', 'wrapperCol', 'colon', 'label', 'labelAlign', 'tooltip', 'extra', 'validateStatus', 'hasFeedback', 'help', 'hidden', 'layout', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFormItem, self).__init__(children=children, **args)

setattr(AntdFormItem, "__init__", _explicitize_args(AntdFormItem.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdAlert(Component):
    """An AntdAlert component.
警告提示组件AntdAlert

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- message (a list of or a singular dash component, string or number; optional):
    主要提示信息内容.

- description (a list of or a singular dash component, string or number; optional):
    额外提示信息内容.

- type (a value equal to: 'success', 'info', 'warning', 'error'; default 'info'):
    提示信息类型，可选项有`'success'`、`'info'`、`'warning'`、`'error'`
    默认值：`'info'`.

- showIcon (boolean; default False):
    是否显示额外图标 默认值：`False`.

- icon (a list of or a singular dash component, string or number; optional):
    组件型，当`showIcon=True`时，用于自定义图标元素.

- closable (boolean; default False):
    是否可关闭 默认值：`False`.

- messageRenderMode (a value equal to: 'default', 'loop-text', 'marquee'; default 'default'):
    渲染模式，可选项有`'default'`、`'loop-text'`、`'marquee'` 默认值：`'default'`.

- action (a list of or a singular dash component, string or number; optional):
    组件型，定义右上角额外操作区元素.

- banner (boolean; default False):
    是否用作顶部公告 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['message', 'description', 'icon', 'action']
    _base_nodes = ['message', 'description', 'icon', 'action', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAlert'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        message: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        type: typing.Optional[Literal["success", "info", "warning", "error"]] = None,
        showIcon: typing.Optional[bool] = None,
        icon: typing.Optional[ComponentType] = None,
        closable: typing.Optional[bool] = None,
        messageRenderMode: typing.Optional[Literal["default", "loop-text", "marquee"]] = None,
        action: typing.Optional[ComponentType] = None,
        banner: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'message', 'description', 'type', 'showIcon', 'icon', 'closable', 'messageRenderMode', 'action', 'banner', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'message', 'description', 'type', 'showIcon', 'icon', 'closable', 'messageRenderMode', 'action', 'banner', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAlert, self).__init__(**args)

setattr(AntdAlert, "__init__", _explicitize_args(AntdAlert.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdModal(Component):
    """An AntdModal component.
对话框组件AntdModal

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - mask (dict; optional):
        遮罩层元素css样式.

    - content (dict; optional):
        容器元素css样式.

    - wrapper (dict; optional):
        包裹层元素css样式.

    - header (dict; optional):
        头部元素css样式.

    - body (dict; optional):
        内容元素css样式.

    - footer (dict; optional):
        底部元素css样式.

- classNames (dict; optional):
    细分控制子元素css类名.

    `classNames` is a dict with keys:

    - mask (string; optional):
        遮罩层元素css类名.

    - content (string; optional):
        容器元素css类名.

    - wrapper (string; optional):
        包裹层元素css类名.

    - header (string; optional):
        头部元素css类名.

    - body (string; optional):
        内容元素css类名.

    - footer (string; optional):
        底部元素css类名.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'ru-ru'`（俄语）
    默认值：`'zh-cn'`.

- visible (boolean; default False):
    监听或设置对话框是否可见 默认值：`False`.

- title (a list of or a singular dash component, string or number; optional):
    组件型，标题内容.

- loadingTitle (a list of or a singular dash component, string or number; optional):
    组件型，loading状态下的标题内容.

- renderFooter (boolean; default False):
    是否渲染底部操作按钮 默认值：`False`.

- okText (a list of or a singular dash component, string or number; optional):
    组件型，确认按钮内容.

- okButtonProps (dict; optional):
    配置确认按钮相关参数.

    `okButtonProps` is a dict with keys:

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险样式 默认值：`False`.

    - disabled (boolean; optional):
        按钮是否呈现禁用状态 默认值：`False`.

    - shape (a value equal to: 'circle', 'round'; optional):
        按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- cancelText (a list of or a singular dash component, string or number; optional):
    组件型，取消按钮内容.

- cancelButtonProps (dict; optional):
    配置取消按钮相关参数.

    `cancelButtonProps` is a dict with keys:

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险样式 默认值：`False`.

    - disabled (boolean; optional):
        按钮是否呈现禁用状态 默认值：`False`.

    - shape (a value equal to: 'circle', 'round'; optional):
        按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- width (dict; default 520):
    对话框像素宽度 默认值：`520`.

    `width` is a number | string | dict with keys:

    - xs (number | string; optional):
        对应页面宽度<576px的响应式断点.

    - sm (number | string; optional):
        对应页面宽度≥576px的响应式断点.

    - md (number | string; optional):
        对应页面宽度≥768px的响应式断点.

    - lg (number | string; optional):
        对应页面宽度≥992px的响应式断点.

    - xl (number | string; optional):
        对应页面宽度≥1200px的响应式断点.

    - xxl (number | string; optional):
        对应页面宽度≥1600px的响应式断点.

- centered (boolean; default False):
    是否垂直居中显示对话框 默认值：`False`.

- keyboard (boolean; default True):
    是否支持键盘esc关闭对话框 默认值：`True`.

- closable (boolean; default True):
    是否显示右上角的关闭按钮 默认值：`True`.

- mask (boolean; default True):
    是否显示背景遮罩 默认值：`True`.

- maskClosable (boolean; default True):
    是否允许点击遮罩层关闭对话框 默认值：`True`.

- okClickClose (boolean; default True):
    是否点击确认按钮触发对话框关闭 默认值：`True`.

- preventClose (boolean; default False):
    是否阻止通过点击关闭图标、点击遮罩层区域、点击取消、按下ESC等方式自动触发的对话框关闭行为 默认值：`False`.

- zIndex (number; default 1000):
    模态框z-index 默认值：`1000`.

- okCounts (number; default 0):
    监听确认按钮累计点击次数 默认值：`0`.

- cancelCounts (number; default 0):
    监听取消按钮累计点击次数 默认值：`0`.

- closeCounts (number; default 0):
    监听关闭按钮累计点击次数 默认值：`0`.

- confirmAutoSpin (boolean; default False):
    是否在每次确认按钮点击之后，自动更新`confirmLoading=True` 默认值：`False`.

- loadingOkText (a list of or a singular dash component, string or number; optional):
    组件型，`confirmLoading=True`时，确认按钮的内容.

- confirmLoading (boolean; default False):
    底部确认按钮是否处于加载中状态 默认值：`False`.

- transitionType (a value equal to: 'none', 'fade', 'zoom', 'zoom-big', 'zoom-big-fast', 'slide-up', 'slide-down', 'slide-left', 'slide-right', 'move-up', 'move-down', 'move-left', 'move-right'; default 'zoom'):
    模态框显隐动画类型，可选项有`'none'`、`'fade'`、`'zoom'`、`'zoom-big'`、`'zoom-big-fast'`、`'slide-up'`、`'slide-down'`、`'slide-left'`、`'slide-right'`、`'move-up'`、`'move-down'`、`'move-left'`、`'move-right'`
    默认值：`'zoom'`.

- forceRender (boolean; default False):
    是否在初始化模态框未显示时，强制渲染模态框内部元素 默认值：`False`.

- destroyOnClose (boolean; default True):
    是否在模态框关闭后自动销毁内部元素 默认值：`True`.

- loading (boolean; default False):
    是否整体渲染为加载中状态 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['title', 'loadingTitle', 'okText', 'cancelText', 'loadingOkText']
    _base_nodes = ['title', 'loadingTitle', 'okText', 'cancelText', 'loadingOkText', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdModal'
    Styles = TypedDict(
        "Styles",
            {
            "mask": NotRequired[dict],
            "content": NotRequired[dict],
            "wrapper": NotRequired[dict],
            "header": NotRequired[dict],
            "body": NotRequired[dict],
            "footer": NotRequired[dict]
        }
    )

    ClassNames = TypedDict(
        "ClassNames",
            {
            "mask": NotRequired[str],
            "content": NotRequired[str],
            "wrapper": NotRequired[str],
            "header": NotRequired[str],
            "body": NotRequired[str],
            "footer": NotRequired[str]
        }
    )

    OkButtonProps = TypedDict(
        "OkButtonProps",
            {
            "size": NotRequired[Literal["small", "middle", "large"]],
            "type": NotRequired[Literal["primary", "ghost", "dashed", "link", "text", "default"]],
            "danger": NotRequired[bool],
            "disabled": NotRequired[bool],
            "shape": NotRequired[Literal["circle", "round"]],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    CancelButtonProps = TypedDict(
        "CancelButtonProps",
            {
            "size": NotRequired[Literal["small", "middle", "large"]],
            "type": NotRequired[Literal["primary", "ghost", "dashed", "link", "text", "default"]],
            "danger": NotRequired[bool],
            "disabled": NotRequired[bool],
            "shape": NotRequired[Literal["circle", "round"]],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    Width = TypedDict(
        "Width",
            {
            "xs": NotRequired[typing.Union[NumberType, str]],
            "sm": NotRequired[typing.Union[NumberType, str]],
            "md": NotRequired[typing.Union[NumberType, str]],
            "lg": NotRequired[typing.Union[NumberType, str]],
            "xl": NotRequired[typing.Union[NumberType, str]],
            "xxl": NotRequired[typing.Union[NumberType, str]]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional["Styles"] = None,
        classNames: typing.Optional["ClassNames"] = None,
        locale: typing.Optional[Literal["zh-cn", "en-us", "de-de", "ru-ru"]] = None,
        visible: typing.Optional[bool] = None,
        title: typing.Optional[ComponentType] = None,
        loadingTitle: typing.Optional[ComponentType] = None,
        renderFooter: typing.Optional[bool] = None,
        okText: typing.Optional[ComponentType] = None,
        okButtonProps: typing.Optional["OkButtonProps"] = None,
        cancelText: typing.Optional[ComponentType] = None,
        cancelButtonProps: typing.Optional["CancelButtonProps"] = None,
        width: typing.Optional[typing.Union[NumberType, str, "Width"]] = None,
        centered: typing.Optional[bool] = None,
        keyboard: typing.Optional[bool] = None,
        closable: typing.Optional[bool] = None,
        mask: typing.Optional[bool] = None,
        maskClosable: typing.Optional[bool] = None,
        okClickClose: typing.Optional[bool] = None,
        preventClose: typing.Optional[bool] = None,
        zIndex: typing.Optional[NumberType] = None,
        okCounts: typing.Optional[NumberType] = None,
        cancelCounts: typing.Optional[NumberType] = None,
        closeCounts: typing.Optional[NumberType] = None,
        confirmAutoSpin: typing.Optional[bool] = None,
        loadingOkText: typing.Optional[ComponentType] = None,
        confirmLoading: typing.Optional[bool] = None,
        transitionType: typing.Optional[Literal["none", "fade", "zoom", "zoom-big", "zoom-big-fast", "slide-up", "slide-down", "slide-left", "slide-right", "move-up", "move-down", "move-left", "move-right"]] = None,
        forceRender: typing.Optional[bool] = None,
        destroyOnClose: typing.Optional[bool] = None,
        loading: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'locale', 'visible', 'title', 'loadingTitle', 'renderFooter', 'okText', 'okButtonProps', 'cancelText', 'cancelButtonProps', 'width', 'centered', 'keyboard', 'closable', 'mask', 'maskClosable', 'okClickClose', 'preventClose', 'zIndex', 'okCounts', 'cancelCounts', 'closeCounts', 'confirmAutoSpin', 'loadingOkText', 'confirmLoading', 'transitionType', 'forceRender', 'destroyOnClose', 'loading', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'locale', 'visible', 'title', 'loadingTitle', 'renderFooter', 'okText', 'okButtonProps', 'cancelText', 'cancelButtonProps', 'width', 'centered', 'keyboard', 'closable', 'mask', 'maskClosable', 'okClickClose', 'preventClose', 'zIndex', 'okCounts', 'cancelCounts', 'closeCounts', 'confirmAutoSpin', 'loadingOkText', 'confirmLoading', 'transitionType', 'forceRender', 'destroyOnClose', 'loading', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdModal, self).__init__(children=children, **args)

setattr(AntdModal, "__init__", _explicitize_args(AntdModal.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdPopupCard(Component):
    """An AntdPopupCard component.
弹出式卡片组件AntdPopupCard

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - mask (dict; optional):
        遮罩层元素css样式.

    - content (dict; optional):
        容器元素css样式.

    - wrapper (dict; optional):
        包裹层元素css样式.

    - header (dict; optional):
        头部元素css样式.

    - body (dict; optional):
        内容元素css样式.

    - footer (dict; optional):
        底部元素css样式.

- classNames (dict; optional):
    细分控制子元素css类名.

    `classNames` is a dict with keys:

    - mask (string; optional):
        遮罩层元素css类名.

    - content (string; optional):
        容器元素css类名.

    - wrapper (string; optional):
        包裹层元素css类名.

    - header (string; optional):
        头部元素css类名.

    - body (string; optional):
        内容元素css类名.

    - footer (string; optional):
        底部元素css类名.

- title (a list of or a singular dash component, string or number; optional):
    组件型，标题内容.

- visible (boolean; default True):
    设置或监听当前弹出式卡片是否显示 默认值：`True`.

- width (number | string; optional):
    弹出式卡片像素宽度.

- transitionType (a value equal to: 'none', 'fade', 'zoom', 'zoom-big', 'zoom-big-fast', 'slide-up', 'slide-down', 'slide-left', 'slide-right', 'move-up', 'move-down', 'move-left', 'move-right'; default 'fade'):
    卡片显隐动画类型，可选项有`'none'`、`'fade'`、`'zoom'`、`'zoom-big'`、`'zoom-big-fast'`、`'slide-up'`、`'slide-down'`、`'slide-left'`、`'slide-right'`、`'move-up'`、`'move-down'`、`'move-left'`、`'move-right'`
    默认值：`'zoom'`.

- forceRender (boolean; default False):
    是否在初始化卡片未显示时，强制渲染卡片内部元素 默认值：`False`.

- destroyOnClose (boolean; default True):
    是否在卡片关闭后自动销毁内部元素 默认值：`True`.

- closable (boolean; default True):
    是否显示右上角的关闭按钮 默认值：`True`.

- closeIconType (a value equal to: 'default', 'outlined', 'two-tone'; default 'default'):
    关闭按钮类型，可选项有`'default'`、`'outlined'`、`'two-tone'` 默认值：`'default'`.

- draggable (boolean; default False):
    是否可拖拽 默认值：`False`.

- dragClassName (string | dict; optional):
    顶部可拖拽区域css类名.

- zIndex (number; default 1000):
    弹出式卡片z-index 默认值：`1000`.

- loading (boolean; default False):
    是否整体渲染为加载中状态 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPopupCard'
    Styles = TypedDict(
        "Styles",
            {
            "mask": NotRequired[dict],
            "content": NotRequired[dict],
            "wrapper": NotRequired[dict],
            "header": NotRequired[dict],
            "body": NotRequired[dict],
            "footer": NotRequired[dict]
        }
    )

    ClassNames = TypedDict(
        "ClassNames",
            {
            "mask": NotRequired[str],
            "content": NotRequired[str],
            "wrapper": NotRequired[str],
            "header": NotRequired[str],
            "body": NotRequired[str],
            "footer": NotRequired[str]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional["Styles"] = None,
        classNames: typing.Optional["ClassNames"] = None,
        title: typing.Optional[ComponentType] = None,
        visible: typing.Optional[bool] = None,
        width: typing.Optional[typing.Union[NumberType, str]] = None,
        transitionType: typing.Optional[Literal["none", "fade", "zoom", "zoom-big", "zoom-big-fast", "slide-up", "slide-down", "slide-left", "slide-right", "move-up", "move-down", "move-left", "move-right"]] = None,
        forceRender: typing.Optional[bool] = None,
        destroyOnClose: typing.Optional[bool] = None,
        closable: typing.Optional[bool] = None,
        closeIconType: typing.Optional[Literal["default", "outlined", "two-tone"]] = None,
        draggable: typing.Optional[bool] = None,
        dragClassName: typing.Optional[typing.Union[str, dict]] = None,
        zIndex: typing.Optional[NumberType] = None,
        loading: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'title', 'visible', 'width', 'transitionType', 'forceRender', 'destroyOnClose', 'closable', 'closeIconType', 'draggable', 'dragClassName', 'zIndex', 'loading', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'title', 'visible', 'width', 'transitionType', 'forceRender', 'destroyOnClose', 'closable', 'closeIconType', 'draggable', 'dragClassName', 'zIndex', 'loading', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdPopupCard, self).__init__(children=children, **args)

setattr(AntdPopupCard, "__init__", _explicitize_args(AntdPopupCard.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdAvatarGroup(Component):
    """An AntdAvatarGroup component.
头像组合组件AntdAvatarGroup

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，传入组内各`AntdAvatar`组件.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- max (dict; optional):
    配置最多显示功能相关参数.

    `max` is a dict with keys:

    - count (number; optional):
        最多显示的头像个数，默认无限制.

    - style (dict; optional):
        头像省略部分css样式.

    - popover (dict; optional):
        展开层相关配置参数.

        `popover` is a dict with keys:

        - placement (a value equal to: 'top', 'bottom', 'right'; optional):
            超出`maxCount`数量限制之外的头像气泡卡片弹出方位，可选项有`'top'`、`'bottom'`、`'right'`
            默认值：`'top'`.

        - trigger (a value equal to: 'hover', 'click'; optional):
            超出`maxCount`数量限制之外的头像气泡卡片弹出触发方式，可选项有`'hover'`、`'click'`
            默认值：`'hover'`.

- size (dict; default 'default'):
    统一设置内部头像尺寸规格，传入数值型表示像素尺寸，传入字符型表示内置规格，可选项有`'large'`、`'small'`、`'default'`，支持响应式断点
    默认值：`'default'`.

    `size` is a number | a value equal to: 'large', 'small', 'default'
    | dict with keys:

    - xs (number; optional)

    - sm (number; optional)

    - md (number; optional)

    - lg (number; optional)

    - xl (number; optional)

    - xxl (number; optional)

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAvatarGroup'
    MaxPopover = TypedDict(
        "MaxPopover",
            {
            "placement": NotRequired[Literal["top", "bottom", "right"]],
            "trigger": NotRequired[Literal["hover", "click"]]
        }
    )

    Max = TypedDict(
        "Max",
            {
            "count": NotRequired[NumberType],
            "style": NotRequired[dict],
            "popover": NotRequired["MaxPopover"]
        }
    )

    Size = TypedDict(
        "Size",
            {
            "xs": NotRequired[NumberType],
            "sm": NotRequired[NumberType],
            "md": NotRequired[NumberType],
            "lg": NotRequired[NumberType],
            "xl": NotRequired[NumberType],
            "xxl": NotRequired[NumberType]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        max: typing.Optional["Max"] = None,
        size: typing.Optional[typing.Union[NumberType, Literal["large", "small", "default"], "Size"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'max', 'size', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'max', 'size', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdAvatarGroup, self).__init__(children=children, **args)

setattr(AntdAvatarGroup, "__init__", _explicitize_args(AntdAvatarGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdStatistic(Component):
    """An AntdStatistic component.
统计数值组件AntdStatistic

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- value (number | string | a list of or a singular dash component, string or number; optional):
    支持组件型，要展示的数值.

- showGroupSeparator (boolean; default True):
    是否为数值型`value`添加千分位符 默认值：`True`.

- precision (number; optional):
    针对数值型`value`，设置数值精度.

- prefix (a list of or a singular dash component, string or number; optional):
    组件型，数值前缀内容.

- suffix (a list of or a singular dash component, string or number; optional):
    组件型，数值后缀内容.

- title (a list of or a singular dash component, string or number; optional):
    组件型，标题内容.

- titleTooltip (string; optional):
    为标题内容添加额外鼠标悬停提示信息.

- valueStyle (dict; optional):
    数值内容css样式.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props: typing.List[str] = ['value', 'prefix', 'suffix', 'title']
    _base_nodes = ['value', 'prefix', 'suffix', 'title', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdStatistic'
    LoadingState = TypedDict(
        "LoadingState",
            {
            "is_loading": NotRequired[bool],
            "prop_name": NotRequired[str],
            "component_name": NotRequired[str]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        value: typing.Optional[typing.Union[NumberType, str, ComponentType]] = None,
        showGroupSeparator: typing.Optional[bool] = None,
        precision: typing.Optional[NumberType] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffix: typing.Optional[ComponentType] = None,
        title: typing.Optional[ComponentType] = None,
        titleTooltip: typing.Optional[str] = None,
        valueStyle: typing.Optional[dict] = None,
        loading_state: typing.Optional["LoadingState"] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'value', 'showGroupSeparator', 'precision', 'prefix', 'suffix', 'title', 'titleTooltip', 'valueStyle', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'value', 'showGroupSeparator', 'precision', 'prefix', 'suffix', 'title', 'titleTooltip', 'valueStyle', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdStatistic, self).__init__(**args)

setattr(AntdStatistic, "__init__", _explicitize_args(AntdStatistic.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdAvatar(Component):
    """An AntdAvatar component.
头像组件AntdAvatar

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- mode (a value equal to: 'text', 'icon', 'image'; default 'icon'):
    头像模式，可选项有`'text'`、`'icon'`、`'image'` 默认值：`'icon'`.

- gap (number; default 4):
    `mode='text'`时，设置字符距离左右两侧边界的像素距离 默认值：`4`.

- text (string; optional):
    `mode='text'`时，设置文字内容.

- icon (string; optional):
    `mode='icon'`时，设置图标，同**AntdIcon**的`icon`参数.

- iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; default 'AntdIcon'):
    `mode='icon'`时，设置图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'`.

- alt (string; optional):
    `mode='image'`时，设置图像无法显示时的占位文字.

- src (string; optional):
    `mode='image'`时，设置图片地址.

- srcSet (string; optional):
    `mode='image'`时，设置图片base64地址.

- draggable (boolean | a value equal to: 'true', 'false'; optional):
    `mode='image'`时，设置图片是否允许拖拽.

- crossOrigin (a value equal to: 'anonymous', 'use-credentials', ''; optional):
    `mode='image'`时，设置图片的CORS属性，可选项有`'anonymous'`、`'use-credentials'`、`''`.

- size (dict; optional):
    配置头像尺寸，可传入数值型代表像素尺寸（支持响应式），或传入字符型使用预设尺寸规格，可选项有`'large'`、`'small'`、`'default'`.

    `size` is a number | a value equal to: 'large', 'small', 'default'
    | dict with keys:

    - xs (number; optional)

    - sm (number; optional)

    - md (number; optional)

    - lg (number; optional)

    - xl (number; optional)

    - xxl (number; optional)

- shape (a value equal to: 'circle', 'square'; default 'circle'):
    头像形状，可选项有`'circle'`、`'square'` 默认值：`'circle'`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAvatar'
    Size = TypedDict(
        "Size",
            {
            "xs": NotRequired[NumberType],
            "sm": NotRequired[NumberType],
            "md": NotRequired[NumberType],
            "lg": NotRequired[NumberType],
            "xl": NotRequired[NumberType],
            "xxl": NotRequired[NumberType]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        mode: typing.Optional[Literal["text", "icon", "image"]] = None,
        gap: typing.Optional[NumberType] = None,
        text: typing.Optional[str] = None,
        icon: typing.Optional[str] = None,
        iconRenderer: typing.Optional[Literal["AntdIcon", "fontawesome"]] = None,
        alt: typing.Optional[str] = None,
        src: typing.Optional[str] = None,
        srcSet: typing.Optional[str] = None,
        draggable: typing.Optional[typing.Union[bool, Literal["true", "false"]]] = None,
        crossOrigin: typing.Optional[Literal["anonymous", "use-credentials", ""]] = None,
        size: typing.Optional[typing.Union[NumberType, Literal["large", "small", "default"], "Size"]] = None,
        shape: typing.Optional[Literal["circle", "square"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'mode', 'gap', 'text', 'icon', 'iconRenderer', 'alt', 'src', 'srcSet', 'draggable', 'crossOrigin', 'size', 'shape', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'mode', 'gap', 'text', 'icon', 'iconRenderer', 'alt', 'src', 'srcSet', 'draggable', 'crossOrigin', 'size', 'shape', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAvatar, self).__init__(**args)

setattr(AntdAvatar, "__init__", _explicitize_args(AntdAvatar.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdMessage(Component):
    """An AntdMessage component.
全局提示组件AntdMessage

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string; optional):
    当前组件css类名.

- content (string; optional):
    提示信息内容.

- type (a value equal to: 'default', 'success', 'error', 'info', 'warning'; default 'default'):
    提示信息类型，可选项有`'default'`、`'success'`、`'error'`、`'info'`、`'warning'`
    默认值：'default'.

- duration (number; default 3):
    提示信息自动消失对应的延时，单位：秒，设置为`0`时不会自动消失 默认值：`3`.

- top (number; default 8):
    提示信息距离顶端的像素距离 默认值：`8`.

- maxCount (number; optional):
    最多允许同时出现的提示信息数量.

- icon (string; optional):
    自定义前缀图标，同`AntdIcon`的`icon`参数.

- iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; default 'AntdIcon'):
    自定义前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'`."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdMessage'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[str] = None,
        content: typing.Optional[str] = None,
        type: typing.Optional[Literal["default", "success", "error", "info", "warning"]] = None,
        duration: typing.Optional[NumberType] = None,
        top: typing.Optional[NumberType] = None,
        maxCount: typing.Optional[NumberType] = None,
        icon: typing.Optional[str] = None,
        iconRenderer: typing.Optional[Literal["AntdIcon", "fontawesome"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'content', 'type', 'duration', 'top', 'maxCount', 'icon', 'iconRenderer']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'key', 'style', 'className', 'content', 'type', 'duration', 'top', 'maxCount', 'icon', 'iconRenderer']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdMessage, self).__init__(**args)

setattr(AntdMessage, "__init__", _explicitize_args(AntdMessage.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdDropdown(Component):
    """An AntdDropdown component.
下拉菜单组件AntdDropdown

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，下拉菜单触发锚定元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- wrapperStyle (dict; optional):
    锚定元素父容器css样式.

- wrapperClassName (string | dict; optional):
    锚定元素父容器css类名.

- title (string; optional):
    下拉菜单触发元素标题内容，children参数未设置时有效.

- buttonMode (boolean; default False):
    下拉菜单触发元素是否渲染为按钮形式，children参数未设置时有效 默认值：`False`.

- buttonProps (dict; optional):
    针对下拉菜单触发元素的按钮形式进行进一步配置.

    `buttonProps` is a dict with keys:

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，按钮图标元素.

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - type (a value equal to: 'default', 'primary', 'ghost', 'dashed', 'link', 'text'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险样式 默认值：`False`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- freePosition (boolean; default False):
    是否开启自由位置模式 默认值：`False`.

- freePositionStyle (dict; optional):
    自由位置模式开启后，控制挂载位置对应css样式.

- freePositionClassName (string; optional):
    自由位置模式开启后，控制挂载位置对应css类名.

- clickedKey (string; optional):
    监听被点击的下拉菜单选项key值.

- nClicks (number; default 0):
    监听下拉菜单选项累计被点击次数 默认值：`0`.

- menuItems (list of dicts; optional):
    下拉菜单数据结构.

    `menuItems` is a list of dicts with keys:

    - title (a list of or a singular dash component, string or number; optional):
        组件型，节点标题.

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，额外内容.

    - href (string; optional):
        节点链接地址.

    - target (string; optional):
        节点链接跳转行为.

    - disabled (boolean; optional):
        是否禁用节点 默认值：`False`.

    - icon (string; optional):
        节点前缀图标名称，与`iconRenderer`方式相关联，`'AntdIcon'`方式下同AntdIcon的icon参数，`'fontawesome'`方式下代表图标的css类名.

    - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional):
        前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'` 默认值：`'AntdIcon'`.

    - key (string; optional):
        节点唯一key值.

    - isDivider (boolean; optional):
        节点是否渲染为分割线.

- selectable (boolean; default False):
    菜单项是否可选择 默认值：`False`.

- multiple (boolean; default False):
    菜单项是否可多选 默认值：`False`.

- selectedKeys (list of strings; optional):
    设置或监听当前已选中菜单项key值.

- nonSelectableKeys (list of strings; optional):
    设置不可选中项key值数组 默认值：`[]`.

- arrow (boolean; default False):
    下拉菜单是否渲染指示箭头 默认值：`False`.

- disabled (boolean; default False):
    是否禁用组件功能 默认值：`False`.

- overlayClassName (string | dict; optional):
    下拉菜单容器css类名，支持[动态css](/advanced-classname).

- overlayStyle (dict; optional):
    下拉菜单容器css样式.

- placement (a value equal to: 'bottomLeft', 'bottomCenter', 'bottomRight', 'topLeft', 'topCenter', 'topRight'; optional):
    下拉菜单弹出方位，可选项有`'bottomLeft'`、`'bottomCenter'`、`'bottomRight'`、`'topLeft'`、`'topCenter'`、`'topRight'`.

- trigger (a value equal to: 'click', 'hover'; default 'hover'):
    下拉菜单显示触发方式，可选项有`'click'`、`'hover'` 默认值：`'hover'`.

- autoAdjustOverflow (boolean; default True):
    下拉菜单是否在被遮挡时自动调整位置 默认值：`True`.

- visible (boolean; default False):
    监听或设置下拉菜单是否展开 默认值：`False`.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    下拉菜单展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

- batchPropsNames (list of strings; optional):
    需要纳入批属性监听的属性名 默认值：`[]`.

- batchPropsValues (dict; optional):
    批量监听与当前batchPropsNames对应的属性值.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['buttonProps.icon', 'menuItems[].title', 'menuItems[].extra']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDropdown'
    ButtonProps = TypedDict(
        "ButtonProps",
            {
            "icon": NotRequired[ComponentType],
            "size": NotRequired[Literal["small", "middle", "large"]],
            "type": NotRequired[Literal["default", "primary", "ghost", "dashed", "link", "text"]],
            "danger": NotRequired[bool],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    MenuItems = TypedDict(
        "MenuItems",
            {
            "title": NotRequired[ComponentType],
            "extra": NotRequired[ComponentType],
            "href": NotRequired[str],
            "target": NotRequired[str],
            "disabled": NotRequired[bool],
            "icon": NotRequired[str],
            "iconRenderer": NotRequired[Literal["AntdIcon", "fontawesome"]],
            "key": NotRequired[str],
            "isDivider": NotRequired[bool]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        wrapperStyle: typing.Optional[dict] = None,
        wrapperClassName: typing.Optional[typing.Union[str, dict]] = None,
        title: typing.Optional[str] = None,
        buttonMode: typing.Optional[bool] = None,
        buttonProps: typing.Optional["ButtonProps"] = None,
        freePosition: typing.Optional[bool] = None,
        freePositionStyle: typing.Optional[dict] = None,
        freePositionClassName: typing.Optional[str] = None,
        clickedKey: typing.Optional[str] = None,
        nClicks: typing.Optional[NumberType] = None,
        menuItems: typing.Optional[typing.Sequence["MenuItems"]] = None,
        selectable: typing.Optional[bool] = None,
        multiple: typing.Optional[bool] = None,
        selectedKeys: typing.Optional[typing.Sequence[str]] = None,
        nonSelectableKeys: typing.Optional[typing.Sequence[str]] = None,
        arrow: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        overlayClassName: typing.Optional[typing.Union[str, dict]] = None,
        overlayStyle: typing.Optional[dict] = None,
        placement: typing.Optional[Literal["bottomLeft", "bottomCenter", "bottomRight", "topLeft", "topCenter", "topRight"]] = None,
        trigger: typing.Optional[Literal["click", "hover"]] = None,
        autoAdjustOverflow: typing.Optional[bool] = None,
        visible: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal["parent", "body"]] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'wrapperStyle', 'wrapperClassName', 'title', 'buttonMode', 'buttonProps', 'freePosition', 'freePositionStyle', 'freePositionClassName', 'clickedKey', 'nClicks', 'menuItems', 'selectable', 'multiple', 'selectedKeys', 'nonSelectableKeys', 'arrow', 'disabled', 'overlayClassName', 'overlayStyle', 'placement', 'trigger', 'autoAdjustOverflow', 'visible', 'popupContainer', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'wrapperStyle', 'wrapperClassName', 'title', 'buttonMode', 'buttonProps', 'freePosition', 'freePositionStyle', 'freePositionClassName', 'clickedKey', 'nClicks', 'menuItems', 'selectable', 'multiple', 'selectedKeys', 'nonSelectableKeys', 'arrow', 'disabled', 'overlayClassName', 'overlayStyle', 'placement', 'trigger', 'autoAdjustOverflow', 'visible', 'popupContainer', 'batchPropsNames', 'batchPropsValues', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDropdown, self).__init__(children=children, **args)

setattr(AntdDropdown, "__init__", _explicitize_args(AntdDropdown.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdFloatButtonGroup(Component):
    """An AntdFloatButtonGroup component.
悬浮按钮组组件AntdFloatButtonGroup

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    当前悬浮按钮组内悬浮按钮.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- icon (a list of or a singular dash component, string or number; optional):
    图标元素.

- description (a list of or a singular dash component, string or number; optional):
    描述内容.

- tooltip (dict; optional):
    气泡卡片内容.

    `tooltip` is a a list of or a singular dash component, string or
    number | dict with keys:

    - title (a list of or a singular dash component, string or number; optional):
        气泡卡片内容.

    - color (string; optional):
        气泡卡片背景色.

    - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight', 'leftTop', 'leftBottom', 'rightTop', 'rightBottom'; optional):
        气泡卡片展开方向，可选项有`'top'`、`'left'`、`'right'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`、`'leftTop'`、`'leftBottom'`、`'rightTop'`、`'rightBottom'`.

- type (a value equal to: 'default', 'primary'; default 'default'):
    按钮类型，可选项有`'default'`、`'primary'` 默认值：`'default'`.

- shape (a value equal to: 'circle', 'square'; default 'circle'):
    内部各悬浮按钮形状，可选项有`'circle'`、`'square'` 默认值：`'circle'`.

- trigger (a value equal to: 'click', 'hover'; optional):
    菜单展开模式触发方式，可选项有`'click'`、`'hover'`.

- placement (a value equal to: 'top', 'right', 'bottom', 'left'; optional):
    菜单展开方向，可选项有`'top'`、`'right'`、`'bottom'`、`'left'`.

- open (boolean; optional):
    设置或监听当前悬浮按钮组展开状态.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['icon', 'description', 'tooltip', 'tooltip.title']
    _base_nodes = ['icon', 'description', 'tooltip', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFloatButtonGroup'
    Tooltip = TypedDict(
        "Tooltip",
            {
            "title": NotRequired[ComponentType],
            "color": NotRequired[str],
            "placement": NotRequired[Literal["top", "left", "right", "bottom", "topLeft", "topRight", "bottomLeft", "bottomRight", "leftTop", "leftBottom", "rightTop", "rightBottom"]]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        icon: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        tooltip: typing.Optional[typing.Union[ComponentType, "Tooltip"]] = None,
        type: typing.Optional[Literal["default", "primary"]] = None,
        shape: typing.Optional[Literal["circle", "square"]] = None,
        trigger: typing.Optional[Literal["click", "hover"]] = None,
        placement: typing.Optional[Literal["top", "right", "bottom", "left"]] = None,
        open: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'icon', 'description', 'tooltip', 'type', 'shape', 'trigger', 'placement', 'open', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'icon', 'description', 'tooltip', 'type', 'shape', 'trigger', 'placement', 'open', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFloatButtonGroup, self).__init__(children=children, **args)

setattr(AntdFloatButtonGroup, "__init__", _explicitize_args(AntdFloatButtonGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdBadge(Component):
    """An AntdBadge component.
徽标组件AntdBadge

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，定义徽标添加目标元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - root (dict; optional):
        控制根元素css样式.

    - indicator (dict; optional):
        控制徽标元素css样式.

- classNames (dict; optional):
    细分控制子元素css类.

    `classNames` is a dict with keys:

    - root (string; optional):
        控制根元素css类.

    - indicator (string; optional):
        控制徽标元素css类.

- color (string; optional):
    徽标颜色.

- count (number; optional):
    徽标显示的数字.

- dot (boolean; default False):
    是否用圆点代替数字显示 默认值：`False`.

- showZero (boolean; default False):
    当`count=0`时，是否强制显示数字 默认值：`False`.

- overflowCount (number; default 99):
    数字显示上限，超出会以显示`+`后缀 默认值：`99`.

- offset (list of numbers; optional):
    徽标在水平、竖直方向上的像素偏移，格式为`[水平偏移, 竖直偏移]`.

- status (a value equal to: 'success', 'processing', 'default', 'error', 'warning'; optional):
    徽标状态，可选项有`'success'`、`'processing'`、`'default'`、`'error'`、`'warning'`.

- text (string; optional):
    参数`status`有效时，设置徽标文本内容.

- title (string; optional):
    徽标鼠标悬停显示文字内容.

- size (a value equal to: 'default', 'small'; default 'default'):
    徽标尺寸规格，可选项有`'default'`、`'small'`.

- nClicks (number; default 0):
    监听徽标累计被点击次数 默认值：`0`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdBadge'
    Styles = TypedDict(
        "Styles",
            {
            "root": NotRequired[dict],
            "indicator": NotRequired[dict]
        }
    )

    ClassNames = TypedDict(
        "ClassNames",
            {
            "root": NotRequired[str],
            "indicator": NotRequired[str]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional["Styles"] = None,
        classNames: typing.Optional["ClassNames"] = None,
        color: typing.Optional[str] = None,
        count: typing.Optional[NumberType] = None,
        dot: typing.Optional[bool] = None,
        showZero: typing.Optional[bool] = None,
        overflowCount: typing.Optional[NumberType] = None,
        offset: typing.Optional[typing.Sequence[NumberType]] = None,
        status: typing.Optional[Literal["success", "processing", "default", "error", "warning"]] = None,
        text: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        size: typing.Optional[Literal["default", "small"]] = None,
        nClicks: typing.Optional[NumberType] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'color', 'count', 'dot', 'showZero', 'overflowCount', 'offset', 'status', 'text', 'title', 'size', 'nClicks', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'color', 'count', 'dot', 'showZero', 'overflowCount', 'offset', 'status', 'text', 'title', 'size', 'nClicks', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdBadge, self).__init__(children=children, **args)

setattr(AntdBadge, "__init__", _explicitize_args(AntdBadge.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdPopconfirm(Component):
    """An AntdPopconfirm component.
气泡确认框组件AntdPopconfirm

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，气泡确认框挂载元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - root (dict; optional):
        根元素（包含箭头、内容元素）css样式.

    - body (dict; optional):
        内容元素css样式.

- classNames (dict; optional):
    细分控制子元素css类名.

    `classNames` is a dict with keys:

    - root (string; optional):
        根元素（包含箭头、内容元素）css类名.

    - body (string; optional):
        内容元素css类名.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'ru-ru'`（俄语）
    默认值：`'zh-cn'`.

- icon (a list of or a singular dash component, string or number; optional):
    组件型，提示图标.

- title (a list of or a singular dash component, string or number; optional):
    组件型，标题内容.

- description (a list of or a singular dash component, string or number; optional):
    组件型，描述内容.

- disabled (boolean; default False):
    是否禁用当前组件 默认值：`False`.

- placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight', 'leftTop', 'leftBottom', 'rightTop', 'rightBottom'; default 'top'):
    气泡确认框弹出位置，可选项有`'top'`、`'left'`、`'right'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`、`'leftTop'`、`'leftBottom'`、`'rightTop'`、`'rightBottom'`
    默认值：`'top'`.

- mouseEnterDelay (number; default 0.1):
    从鼠标移入挂载元素，到气泡确认框显示的延时，单位：秒 默认值：`0.1`.

- mouseLeaveDelay (number; default 0.1):
    从鼠标移出挂载元素，到气泡确认框消失的延时，单位：秒 默认值：`0.1`.

- okText (a list of or a singular dash component, string or number; optional):
    组件型，确认按钮内容.

- okButtonProps (dict; optional):
    配置确认按钮相关参数.

    `okButtonProps` is a dict with keys:

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险样式 默认值：`False`.

    - disabled (boolean; optional):
        按钮是否呈现禁用状态 默认值：`False`.

    - shape (a value equal to: 'circle', 'round'; optional):
        按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- cancelText (a list of or a singular dash component, string or number; optional):
    组件型，取消按钮内容.

- cancelButtonProps (dict; optional):
    配置取消按钮相关参数.

    `cancelButtonProps` is a dict with keys:

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险样式 默认值：`False`.

    - disabled (boolean; optional):
        按钮是否呈现禁用状态 默认值：`False`.

    - shape (a value equal to: 'circle', 'round'; optional):
        按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- showCancel (boolean; default True):
    是否显示取消按钮 默认值：`True`.

- confirmCounts (number; default 0):
    监听确认按钮累计点击次数 默认值：`0`.

- cancelCounts (number; default 0):
    监听取消按钮累计点击次数 默认值：`0`.

- trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; default 'click'):
    气泡确认框触发行为，可选项有`'hover'`、`'focus'`、`'click'`，可多选组合 默认值：`'click'`.

- zIndex (number; optional):
    气泡确认框z-index.

- arrow (a value equal to: 'show', 'hide', 'center'; default 'show'):
    指示箭头显示形式，可选项有`'show'`、`'hide'`、`'center'` 默认值：`'show'`.

- fresh (boolean; default False):
    是否保持内容更新 默认值：`False`.

- open (boolean; default False):
    监听或设置气泡确认框的显示状态 默认值：`False`.

- permanent (boolean; default False):
    是否保持气泡确认框显示/隐藏 默认值：`False`.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    悬浮层渲染挂载父节点策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props: typing.List[str] = ['icon', 'title', 'description', 'okText', 'cancelText']
    _base_nodes = ['icon', 'title', 'description', 'okText', 'cancelText', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPopconfirm'
    Styles = TypedDict(
        "Styles",
            {
            "root": NotRequired[dict],
            "body": NotRequired[dict]
        }
    )

    ClassNames = TypedDict(
        "ClassNames",
            {
            "root": NotRequired[str],
            "body": NotRequired[str]
        }
    )

    OkButtonProps = TypedDict(
        "OkButtonProps",
            {
            "size": NotRequired[Literal["small", "middle", "large"]],
            "type": NotRequired[Literal["primary", "ghost", "dashed", "link", "text", "default"]],
            "danger": NotRequired[bool],
            "disabled": NotRequired[bool],
            "shape": NotRequired[Literal["circle", "round"]],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    CancelButtonProps = TypedDict(
        "CancelButtonProps",
            {
            "size": NotRequired[Literal["small", "middle", "large"]],
            "type": NotRequired[Literal["primary", "ghost", "dashed", "link", "text", "default"]],
            "danger": NotRequired[bool],
            "disabled": NotRequired[bool],
            "shape": NotRequired[Literal["circle", "round"]],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    LoadingState = TypedDict(
        "LoadingState",
            {
            "is_loading": NotRequired[bool],
            "prop_name": NotRequired[str],
            "component_name": NotRequired[str]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional["Styles"] = None,
        classNames: typing.Optional["ClassNames"] = None,
        locale: typing.Optional[Literal["zh-cn", "en-us", "de-de", "ru-ru"]] = None,
        icon: typing.Optional[ComponentType] = None,
        title: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        disabled: typing.Optional[bool] = None,
        placement: typing.Optional[Literal["top", "left", "right", "bottom", "topLeft", "topRight", "bottomLeft", "bottomRight", "leftTop", "leftBottom", "rightTop", "rightBottom"]] = None,
        mouseEnterDelay: typing.Optional[NumberType] = None,
        mouseLeaveDelay: typing.Optional[NumberType] = None,
        okText: typing.Optional[ComponentType] = None,
        okButtonProps: typing.Optional["OkButtonProps"] = None,
        cancelText: typing.Optional[ComponentType] = None,
        cancelButtonProps: typing.Optional["CancelButtonProps"] = None,
        showCancel: typing.Optional[bool] = None,
        confirmCounts: typing.Optional[NumberType] = None,
        cancelCounts: typing.Optional[NumberType] = None,
        trigger: typing.Optional[typing.Union[Literal["hover", "focus", "click"], typing.Sequence[Literal["hover", "focus", "click"]]]] = None,
        zIndex: typing.Optional[NumberType] = None,
        arrow: typing.Optional[Literal["show", "hide", "center"]] = None,
        fresh: typing.Optional[bool] = None,
        open: typing.Optional[bool] = None,
        permanent: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal["parent", "body"]] = None,
        loading_state: typing.Optional["LoadingState"] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'locale', 'icon', 'title', 'description', 'disabled', 'placement', 'mouseEnterDelay', 'mouseLeaveDelay', 'okText', 'okButtonProps', 'cancelText', 'cancelButtonProps', 'showCancel', 'confirmCounts', 'cancelCounts', 'trigger', 'zIndex', 'arrow', 'fresh', 'open', 'permanent', 'popupContainer', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'styles', 'classNames', 'locale', 'icon', 'title', 'description', 'disabled', 'placement', 'mouseEnterDelay', 'mouseLeaveDelay', 'okText', 'okButtonProps', 'cancelText', 'cancelButtonProps', 'showCancel', 'confirmCounts', 'cancelCounts', 'trigger', 'zIndex', 'arrow', 'fresh', 'open', 'permanent', 'popupContainer', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdPopconfirm, self).__init__(children=children, **args)

setattr(AntdPopconfirm, "__init__", _explicitize_args(AntdPopconfirm.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdAnchor(Component):
    """An AntdAnchor component.
锚点组件AntdAnchor

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- linkDict (optional):
    目录层次数据结构.

- direction (a value equal to: 'vertical', 'horizontal'; default 'vertical'):
    导航方向，可选项有`'vertical'`、`'horizontal'`，其中`'horizontal'`方向下不支持子目录
    默认值：`'vertical'`.

- align (a value equal to: 'left', 'right'; default 'right'):
    锚点位置，可选项有`'left'`、`'right'` 默认值：`'right'`.

- containerId (string; optional):
    锚点目标容器id.

- targetOffset (number; optional):
    锚点位移偏移量，默认同参数offsetTop.

- affix (boolean; default True):
    是否开启固定模式 默认值：`True`.

- bounds (number; default 5):
    锚点像素边距 默认值：`5`.

- offsetTop (number; optional):
    设置距离窗口顶部触发锚定效果的指定像素偏移量.

- replace (boolean; default False):
    设置为`True`后，浏览器后退或前进时，不会跳转到锚点地址 默认值：`False`.

- currentAnchor (string; optional):
    强制指定当前处于高亮状态的锚点链接.

- clickedLink (dict; optional):
    监听锚点节点点击事件.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAnchor'


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        linkDict: typing.Optional[typing.Any] = None,
        direction: typing.Optional[Literal["vertical", "horizontal"]] = None,
        align: typing.Optional[Literal["left", "right"]] = None,
        containerId: typing.Optional[str] = None,
        targetOffset: typing.Optional[NumberType] = None,
        affix: typing.Optional[bool] = None,
        bounds: typing.Optional[NumberType] = None,
        offsetTop: typing.Optional[NumberType] = None,
        replace: typing.Optional[bool] = None,
        currentAnchor: typing.Optional[str] = None,
        clickedLink: typing.Optional[dict] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'linkDict', 'direction', 'align', 'containerId', 'targetOffset', 'affix', 'bounds', 'offsetTop', 'replace', 'currentAnchor', 'clickedLink', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'linkDict', 'direction', 'align', 'containerId', 'targetOffset', 'affix', 'bounds', 'offsetTop', 'replace', 'currentAnchor', 'clickedLink', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAnchor, self).__init__(**args)

setattr(AntdAnchor, "__init__", _explicitize_args(AntdAnchor.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdUpload(Component):
    """An AntdUpload component.
文件上传组件AntdUpload

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- name (string; optional):
    配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

- enableBatchControl (boolean; default True):
    控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'ru-ru'`（俄语）
    默认值：`'zh-cn'`.

- apiUrl (string; optional):
    文件上传服务接口地址.

- apiUrlExtraParams (dict; optional):
    文件上传服务接口额外参数.

- headers (dict; optional):
    文件上传服务接口额外headers参数.

- withCredentials (boolean; default False):
    是否在请求上传服务接口时自动携带cookies等凭据信息 默认值：`False`.

- withOriginFileObj (boolean; default False):
    `listUploadTaskRecord`监听结果中是否额外记录浏览器原生`originFileObj`相关信息
    默认值：`False`.

- downloadUrl (string; optional):
    对应已上传文件的`GET`类型下载服务接口地址，自带参数`taskId`、`filename`.

- downloadUrlExtraParams (dict; optional):
    配合`downloadUrl`参数，设置文件下载服务接口额外参数.

- downloadUrlFromBackend (boolean; default False):
    是否将文件上传接口返回信息中的`url`属性作为下载链接地址 默认值：`False`.

- fileListMaxLength (number; optional):
    限制已上传文件列表长度上限.

- fileTypes (list of strings; optional):
    允许上传的文件后缀名列表，默认不限制.

- buttonContent (a list of or a singular dash component, string or number; optional):
    组件型，自定义上传按钮内容.

- buttonIcon (a list of or a singular dash component, string or number; optional):
    组件型，自定义上传按钮图标.

- buttonProps (dict; optional):
    配置上传按钮相关参数.

    `buttonProps` is a dict with keys:

    - size (a value equal to: 'default', 'small', 'large'; optional):
        按钮尺寸规格，可选项有`'default'`、`'small'`、`'large'` 默认值：`'default'`.

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否渲染危险状态 默认值：`False`.

    - block (boolean; optional):
        按钮是否撑满父元素 默认值：`False`.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

- uploadId (string; optional):
    自定义当前组件发起文件上传请求时携带的`uploadId`参数，可用于辅助后端创建文件上传所在文件夹.

- fileMaxSize (number; default 500):
    文件上传尺寸上限，单位：兆.

- multiple (boolean; default False):
    是否开启多文件上传模式 默认值：`False`.

- directory (boolean; default False):
    是否开启文件夹上传模式 默认值：`False`.

- failedTooltipInfo (string; optional):
    文件上传失败消息提示文字内容 默认值：`'上传失败'`.

- showUploadList (boolean; default True):
    是否显示已上传文件列表 默认值：`True`.

- confirmBeforeDelete (boolean; default False):
    是否为已上传文件删除操作添加二次确认模态框 默认值：`False`.

- showPercent (boolean; default False):
    是否显示上传进度条 默认值：`False`.

- progressProps (dict; optional):
    配置上传进度条相关参数.

    `progressProps` is a dict with keys:

    - strokeColor (dict; optional):
        进度条颜色.

        `strokeColor` is a string

      Or dict with keys:

        - from (string; optional):

            渐变色开始颜色.

        - to (string; optional):

            渐变色结束颜色.

    - strokeWidth (number; optional):
        进度条像素宽度.

    - format (dict; optional):
        进度文字格式.

        `format` is a dict with keys:

        - prefix (string; optional):
            进度文字前缀内容.

        - suffix (string; optional):
            进度文字后缀内容 默认值：`'%'`.

- showSuccessMessage (boolean; default True):
    是否在每个文件上传成功后，分别弹出消息提示 默认值：`True`.

- showErrorMessage (boolean; default True):
    是否在每个文件上传失败后，分别弹出消息提示 默认值：`True`.

- pastable (boolean; default False):
    是否开启粘贴上传，即本地复制文件后，在页面任意位置粘贴即可完成上传 默认值：`False`.

- lastUploadTaskRecord (dict; optional):
    监听最近一次文件上传任务相关信息.

    `lastUploadTaskRecord` is a dict with keys:

    - fileName (string; optional):
        文件名称.

    - fileSize (number; optional):
        文件大小.

    - completeTimestamp (number; optional):
        上传完成时间戳.

    - taskStatus (string; optional):
        上传任务状态，`'success'`表示成功，`'failed'`表示失败.

    - taskId (string; optional):
        上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

    - url (string; optional):
        当前文件的下载链接.

    - uploadResponse (boolean | number | string | dict | list; optional):
        上传任务的接口响应信息. | list of dicts with keys:

    - fileName (string; optional):
        文件名称.

    - fileSize (number; optional):
        文件大小.

    - completeTimestamp (number; optional):
        上传完成时间戳.

    - taskStatus (string; optional):
        上传任务状态，`'success'`表示成功，`'failed'`表示失败.

    - taskId (string; optional):
        上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

    - url (string; optional):
        当前文件的下载链接.

    - uploadResponse (boolean | number | string | dict | list; optional):
        上传任务的接口响应信息.

- listUploadTaskRecord (list of dicts; optional):
    监听当前已上传文件列表中上传任务相关信息.

    `listUploadTaskRecord` is a list of dicts with keys:

    - fileName (string; optional):
        文件名称.

    - fileSize (number; optional):
        文件大小.

    - completeTimestamp (number; optional):
        上传完成时间戳.

    - taskStatus (string; optional):
        上传任务状态，`'success'`表示成功，`'failed'`表示失败.

    - taskId (string; optional):
        上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

    - uid (string; optional):
        当前文件上传唯一识别id，前端自动生成.

    - url (string; optional):
        当前文件下载链接.

    - uploadResponse (boolean | number | string | dict | list; optional):
        上传任务的接口响应信息.

    - originFileObj (boolean | number | string | dict | list; optional):
        当`withOriginFileObj=True`时，监听当前文件上传任务对应的`originFileObj`主要信息.

- defaultFileList (list of dicts; optional):
    初始化文件列表展示信息.

    `defaultFileList` is a list of dicts with keys:

    - name (string; optional):
        当前文件名称.

    - status (a value equal to: 'done', 'error', 'removed'; optional):
        当前文件展示状态，可选项有`'done'`、`'error'`、`'removed'`.

    - uid (boolean | number | string | dict | list; optional):
        当前文件唯一识别id.

    - url (string; optional):
        当前文件下载链接.

    - taskId (string; optional):
        若传入有效值，将作为当前组件的`uploadId`参数.

    - fileSize (number; optional):
        当前文件大小.

- disabled (boolean; default False):
    是否禁用当前组件 默认值：`False`.

- status (a value equal to: 'error', 'warning'; optional):
    控制校验状态，可选项有`'error'`、`'warning'`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props: typing.List[str] = ['buttonContent', 'buttonIcon']
    _base_nodes = ['buttonContent', 'buttonIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdUpload'
    ButtonProps = TypedDict(
        "ButtonProps",
            {
            "size": NotRequired[Literal["default", "small", "large"]],
            "type": NotRequired[Literal["primary", "ghost", "dashed", "link", "text", "default"]],
            "danger": NotRequired[bool],
            "block": NotRequired[bool],
            "style": NotRequired[dict],
            "className": NotRequired[str]
        }
    )

    ProgressPropsStrokeColor = TypedDict(
        "ProgressPropsStrokeColor",
            {
            "from": NotRequired[str],
            "to": NotRequired[str]
        }
    )

    ProgressPropsFormat = TypedDict(
        "ProgressPropsFormat",
            {
            "prefix": NotRequired[str],
            "suffix": NotRequired[str]
        }
    )

    ProgressProps = TypedDict(
        "ProgressProps",
            {
            "strokeColor": NotRequired[typing.Union[str, "ProgressPropsStrokeColor"]],
            "strokeWidth": NotRequired[NumberType],
            "format": NotRequired["ProgressPropsFormat"]
        }
    )

    LastUploadTaskRecord = TypedDict(
        "LastUploadTaskRecord",
            {
            "fileName": NotRequired[str],
            "fileSize": NotRequired[NumberType],
            "completeTimestamp": NotRequired[NumberType],
            "taskStatus": NotRequired[str],
            "taskId": NotRequired[str],
            "url": NotRequired[str],
            "uploadResponse": NotRequired[typing.Any]
        }
    )

    ListUploadTaskRecord = TypedDict(
        "ListUploadTaskRecord",
            {
            "fileName": NotRequired[str],
            "fileSize": NotRequired[NumberType],
            "completeTimestamp": NotRequired[NumberType],
            "taskStatus": NotRequired[str],
            "taskId": NotRequired[str],
            "uid": NotRequired[str],
            "url": NotRequired[str],
            "uploadResponse": NotRequired[typing.Any],
            "originFileObj": NotRequired[typing.Any]
        }
    )

    DefaultFileList = TypedDict(
        "DefaultFileList",
            {
            "name": NotRequired[str],
            "status": NotRequired[Literal["done", "error", "removed"]],
            "uid": NotRequired[typing.Any],
            "url": NotRequired[str],
            "taskId": NotRequired[str],
            "fileSize": NotRequired[NumberType]
        }
    )

    LoadingState = TypedDict(
        "LoadingState",
            {
            "is_loading": NotRequired[bool],
            "prop_name": NotRequired[str],
            "component_name": NotRequired[str]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal["zh-cn", "en-us", "de-de", "ru-ru"]] = None,
        apiUrl: typing.Optional[str] = None,
        apiUrlExtraParams: typing.Optional[dict] = None,
        headers: typing.Optional[dict] = None,
        withCredentials: typing.Optional[bool] = None,
        withOriginFileObj: typing.Optional[bool] = None,
        downloadUrl: typing.Optional[str] = None,
        downloadUrlExtraParams: typing.Optional[dict] = None,
        downloadUrlFromBackend: typing.Optional[bool] = None,
        fileListMaxLength: typing.Optional[NumberType] = None,
        fileTypes: typing.Optional[typing.Sequence[str]] = None,
        buttonContent: typing.Optional[ComponentType] = None,
        buttonIcon: typing.Optional[ComponentType] = None,
        buttonProps: typing.Optional["ButtonProps"] = None,
        uploadId: typing.Optional[str] = None,
        fileMaxSize: typing.Optional[NumberType] = None,
        multiple: typing.Optional[bool] = None,
        directory: typing.Optional[bool] = None,
        failedTooltipInfo: typing.Optional[str] = None,
        showUploadList: typing.Optional[bool] = None,
        confirmBeforeDelete: typing.Optional[bool] = None,
        showPercent: typing.Optional[bool] = None,
        progressProps: typing.Optional["ProgressProps"] = None,
        showSuccessMessage: typing.Optional[bool] = None,
        showErrorMessage: typing.Optional[bool] = None,
        pastable: typing.Optional[bool] = None,
        lastUploadTaskRecord: typing.Optional[typing.Union["LastUploadTaskRecord", typing.Sequence["LastUploadTaskRecord"]]] = None,
        listUploadTaskRecord: typing.Optional[typing.Sequence["ListUploadTaskRecord"]] = None,
        defaultFileList: typing.Optional[typing.Sequence["DefaultFileList"]] = None,
        disabled: typing.Optional[bool] = None,
        status: typing.Optional[Literal["error", "warning"]] = None,
        loading_state: typing.Optional["LoadingState"] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'name', 'enableBatchControl', 'locale', 'apiUrl', 'apiUrlExtraParams', 'headers', 'withCredentials', 'withOriginFileObj', 'downloadUrl', 'downloadUrlExtraParams', 'downloadUrlFromBackend', 'fileListMaxLength', 'fileTypes', 'buttonContent', 'buttonIcon', 'buttonProps', 'uploadId', 'fileMaxSize', 'multiple', 'directory', 'failedTooltipInfo', 'showUploadList', 'confirmBeforeDelete', 'showPercent', 'progressProps', 'showSuccessMessage', 'showErrorMessage', 'pastable', 'lastUploadTaskRecord', 'listUploadTaskRecord', 'defaultFileList', 'disabled', 'status', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'name', 'enableBatchControl', 'locale', 'apiUrl', 'apiUrlExtraParams', 'headers', 'withCredentials', 'withOriginFileObj', 'downloadUrl', 'downloadUrlExtraParams', 'downloadUrlFromBackend', 'fileListMaxLength', 'fileTypes', 'buttonContent', 'buttonIcon', 'buttonProps', 'uploadId', 'fileMaxSize', 'multiple', 'directory', 'failedTooltipInfo', 'showUploadList', 'confirmBeforeDelete', 'showPercent', 'progressProps', 'showSuccessMessage', 'showErrorMessage', 'pastable', 'lastUploadTaskRecord', 'listUploadTaskRecord', 'defaultFileList', 'disabled', 'status', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdUpload, self).__init__(**args)

setattr(AntdUpload, "__init__", _explicitize_args(AntdUpload.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdHeader(Component):
    """An AntdHeader component.
页首组件AntdHeader

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdHeader'


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdHeader, self).__init__(children=children, **args)

setattr(AntdHeader, "__init__", _explicitize_args(AntdHeader.__init__))
